package com.ruoyi.ss.carousel.service;

import com.ruoyi.ss.carousel.domain.Carousel;
import com.ruoyi.ss.carousel.domain.CarouselQuery;
import com.ruoyi.ss.carousel.domain.CarouselVO;

import java.util.List;

/**
 * 轮播图Service接口
 *
 * @author qzz
 * @date 2024-12-13
 */
public interface CarouselService
{
    /**
     * 查询轮播图
     *
     * @param carouselId 轮播图主键
     * @return 轮播图
     */
    public CarouselVO selectSsCarouselByCarouselId(Long carouselId);

    /**
     * 查询轮播图列表
     *
     * @param ssCarousel 轮播图
     * @return 轮播图集合
     */
    public List<CarouselVO> selectSsCarouselList(CarouselQuery ssCarousel);

    /**
     * 新增轮播图
     *
     * @param ssCarousel 轮播图
     * @return 结果
     */
    public int insertSsCarousel(Carousel ssCarousel);

    /**
     * 修改轮播图
     *
     * @param ssCarousel 轮播图
     * @return 结果
     */
    public int updateSsCarousel(Carousel ssCarousel);

    /**
     * 批量删除轮播图
     *
     * @param carouselIds 需要删除的轮播图主键集合
     * @return 结果
     */
    public int deleteSsCarouselByCarouselIds(Long[] carouselIds);

    /**
     * 删除轮播图信息
     *
     * @param carouselId 轮播图主键
     * @return 结果
     */
    public int deleteSsCarouselByCarouselId(Long carouselId);

    /**
     * 根据店铺id查询轮播图
     * @param storeId
     * @return
     */
    List<CarouselVO> selectSsCarouselListByStoreId(Long storeId);
}
